% 2D self-similar solutions for primary 
% wave energy, length and direction in moving TC 
% (Eq. 7 of ... ) relative to ones in stationary TC.

clear
close all
clc

Rm=50; Um=50;
Vtrans=[3 7 12];


fname=[pwd,filesep,'TC_Wave_GMF.nc'];
MAT.TH = ncread(fname,'TH');
MAT.X = ncread(fname,'X');
MAT.E = ncread(fname,'E');
MAT.L = ncread(fname,'L');
MAT.F = ncread(fname,'F');


%___Grid
x=[-3:0.1:3]*Rm; y=[-3:0.1:3]*Rm; 
[XX,YY]=meshgrid(x,y);
R=sqrt(XX.^2+YY.^2); %km
R(R>max(XX(:))*1.03)=NaN;
TH=atan2d(YY,XX); 
TH=-(TH-90); TH(TH>180)=TH(TH>180)-360; %CW from north

%___Wind
latf=30; f=2*7.2921e-5*sind(latf); B=1.5;
U=sqrt((Um^2+Um*Rm*f).*(Rm./R).^B.*exp(-(Rm./R).^B)./exp(-1)+R.^2*f^2/4)-R*f/2;
DIRU=atan2d(YY,XX)+90+20; 

%__Stationary TC
[H0,L0,Hd,Ld,F]=fun_TC0_jgr(Rm*1000,Um,R*1000);


%___Moving TC
HV=[]; LV=[]; DIRV=[];
for iv=1:length(Vtrans)
V=Vtrans(iv);
q=-1/4; ca=11.8; 
Lcr1 =-ca^(-1/q)*q/(1+q)*(U.^2./9.8).*(U./2./V).^(1/q); 
Xd=(R*1000./Lcr1); 

HV(:,:,iv)=H0.*interp2(MAT.TH,MAT.X,sqrt(MAT.E),TH,Xd,'linear');
LV(:,:,iv)=L0.*interp2(MAT.TH,MAT.X,MAT.L,TH,Xd);
DIRV(:,:,iv)=DIRU+interp2(MAT.TH,MAT.X,MAT.F,TH,Xd)+F;
end


%___PLOT_____Vtrans=0;

set(figure(1),'position',[600 580 1300 400]);
subplot(1,3,1); colormap(jet(300));
imagesc(x/Rm,y/Rm,U); hold on;
dq=7; quiver(x(1:dq:end,1:dq:end)/Rm,y(1:dq:end,1:dq:end)/Rm,U(1:dq:end,1:dq:end).*cosd(DIRU(1:dq:end,1:dq:end)),U(1:dq:end,1:dq:end).*sind(DIRU(1:dq:end,1:dq:end)),'k','linewidth',1.5); warning off;
set(gca,'ydir','normal');  colorbar;
set(gca,'xtick',[-6:2:6],'ytick',[-6:2:6]);
axis equal tight;
axis([-max(x)/Rm max(x)/Rm -max(x)/Rm max(x)/Rm]);
xlabel('R/Rm'); ylabel('R/Rm');
title(['Rm=',num2str(Rm),', Um=',num2str(Um),', Wind, m/s']);
caxis([10,max(U(:))]);
set(gca,'fontsize',13);

subplot(1,3,2); 
imagesc(x/Rm,y/Rm,H0); hold on;
set(gca,'ydir','normal');  colorbar;
set(gca,'xtick',[-6:2:6],'ytick',[-6:2:6]);
axis equal tight;
axis([-max(x)/Rm max(x)/Rm -max(x)/Rm max(x)/Rm]);
xlabel('R/Rm'); %ylabel('R/Rm');
title('Hs_0, m');
caxis([2,max(H0(:))]);
set(gca,'fontsize',13);

subplot(1,3,3); 
imagesc(x/Rm,y/Rm,L0); hold on;
set(gca,'ydir','normal'); colorbar;
set(gca,'xtick',[-6:2:6],'ytick',[-6:2:6]);
axis equal tight;
axis([-max(x)/Rm max(x)/Rm -max(x)/Rm max(x)/Rm]);
xlabel('R/Rm'); %ylabel('R/Rm');
title('\lambda_0, m');
caxis([50,max(L0(:))]);
set(gca,'fontsize',13);


%___PLOT_____Moving TC;
set(figure(2),'position',[600 50 1300 700]); 

for iv=1:length(Vtrans)
subplot(2,3,iv); colormap(jet(300));
imagesc(x/Rm,y/Rm,HV(:,:,iv)); hold on;
set(gca,'ydir','normal'); clb=colorbar; title(clb,'Hs,m');
set(gca,'xtick',[-6:2:6],'ytick',[-6:2:6]);
axis equal tight; 
axis([-max(x)/Rm max(x)/Rm -max(x)/Rm max(x)/Rm]);
xlabel('R/Rm'); ylabel('R/Rm');
title(['Rm=',num2str(Rm),', Um=',num2str(Um),', ','V=',num2str(Vtrans(iv)),'m/s']);
caxis([0,max(max(max(HV(:,:,:))))]);
set(gca,'fontsize',13);

subplot(2,3,3+iv); colormap(jet);
imagesc(x/Rm,y/Rm,LV(:,:,iv)); hold on;
dq=6; 
quiver(x(1:dq:end,1:dq:end)/Rm,y(1:dq:end,1:dq:end)/Rm,cosd(DIRV(1:dq:end,1:dq:end,iv)).*(LV(1:dq:end,1:dq:end,iv)),sind(DIRV(1:dq:end,1:dq:end,iv)).*(LV(1:dq:end,1:dq:end,iv)),'k','linewidth',1.5); warning off;
set(gca,'ydir','normal');  clb=colorbar; title(clb,'\lambda,m');
set(gca,'xtick',[-6:2:6],'ytick',[-6:2:6]);
axis equal tight;
axis([-max(x)/Rm max(x)/Rm -max(x)/Rm max(x)/Rm]);
xlabel('R/Rm'); ylabel('R/Rm');
caxis([50,max(max(max(LV(:,:,:))))]);
set(gca,'fontsize',13);
drawnow;
end







